:py:mod:`piel.models.physical.electronic.straight`
==================================================

.. py:module:: piel.models.physical.electronic.straight


Module Contents
---------------

Classes
~~~~~~~

.. autoapisummary::

   piel.models.physical.electronic.straight.StraightParameters



Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.electronic.straight.straight



.. py:class:: StraightParameters


   These are all the potential parametric configuration variables


.. py:function:: straight(params: StraightParameters) -> hdl21.Module

   Implements a `hdl21` taper resistor class.
